@@ -106,7 +106,8 @@ class CLI(cl1.CLI):
 		elif self.argument_present('--generate'):
 			
 			# generate a key.
-			passphrase = self.get_passphrase()
+			passphrase = self.get_passphrase(required=False)
+			if passphrase in ["", None, "null", "None", "none"]: passphrase = None
 			response = key.generate(
 				directory=self.get_argument("--path"), 
 				passphrase=passphrase, 
@@ -119,8 +120,8 @@ class CLI(cl1.CLI):
 			print("Selected an invalid mode.")
 
 		#
-	def get_passphrase(self):
-		return self.get_argument("--passphrase").replace("\\", "").replace("\ ", "")
+	def get_passphrase(self, required=True):
+		return self.get_argument("--passphrase", required=required).replace("\\", "").replace("\ ", "")
 # main.
 if __name__ == "__main__":
 	cli = CLI()
