@@ -150,6 +150,8 @@ class Config(object):
 		key=None,
 		# smart card.
 		smart_card=False,
+		# overwrite default alias.
+		alias=None,
 	):
 		
 		# checks.
@@ -174,9 +176,13 @@ class Config(object):
 				os.system("chmod 700 "+f'{HOME}/.ssh')
 		
 		# create config.
-		tag = f'# ID: {username}@{server} '+'{'
+		if alias == None: 
+			alias = f"{username}.{server}"
+			tag = f'# ID: {username}@{server} '+'{'
+		else:
+			tag = f'# ID: {alias} '+'{'
 		config = f"\n{tag}"
-		config += f"\nHost {username}.{server}"
+		config += f"\nHost {alias}"
 		config += "\n    HostName {}".format(ip)
 		config += "\n    Port {}".format(port)
 		config += "\n    User {}".format(username)
@@ -639,7 +645,7 @@ class SSHFS(object):
 	):
 
 		# checks.
-		base = []
+		base = ""
 		if alias == None:
 			success, response = utils.__check_parameters__(empty_value=None, parameters={
 				"username":username,
@@ -650,7 +656,7 @@ class SSHFS(object):
 				"port":port,
 			})
 			if not success: return response
-			base += ["sshfs"]
+			base += f"sshfs -p {port} -o IdentityFile={key_path} {username}@{ip}"
 		else:
 			success, response = utils.__check_parameters__(empty_value=None, parameters={
 				"alias":alias,
@@ -658,11 +664,11 @@ class SSHFS(object):
 				"client_path":client_path,
 			})
 			if not success: return response
-			base += ["sshfs", "-p", str(port), "-o", f"IdentityFile={key_path}"]
-			alias = f'{username}@{ip}'
+			base += f'sshfs {username}@{ip}'
 
 		# do.
-		output = utils.__execute__(base + [f'{alias}:{server_path}', client_path])
+		output = utils.__execute_script__(f'{base}:{server_path} {client_path}')
+		#output = utils.__execute__(base + [f'{alias}:{server_path}', client_path])
 		#output = utils.__execute_script__(utils.__array_to_string__(base + [f'{alias}:{server_path}', client_path], joiner="\n"))
 
 		# check fails.
